==> babel-plugin-house-1.0.10.tgz: package/src/mobxPatch.js <==
const babel = require('babel-core');
const t = require('babel-types');
const utils = require('./utils');

function transExpressionStatement(path) {
  const node = path.node;
  if (t.isCallExpression(node.expression)) {
    if (t.isIdentifier(node.expression.callee) && node.expression.callee.name === 'endAction') {
      let args = node.expression.arguments;
      args = args.concat(t.identifier('actionName'));
      node.expression.arguments = args;
    }
  }
}

function transFunctionDeclaration(path) {
  const node = path.node;
  if (t.isIdentifier(path.node.id) && node.id.name === 'executeAction') {
    if (t.isBlockStatement(node.body)) {
      let express = utils.addLog(path.node.id.name);
      node.body.body.unshift(express);
      for (let item of node.body.body) {
        if (t.isExpressionStatement(item) && t.isCallExpression(item.expression)) {
          if (t.isIdentifier(item.expression.callee) && item.expression.callee.name === 'endAction') {
            let args = item.expression.arguments;
            args = args.concat(t.identifier('actionName'));
            item.expression.arguments = args;
            break;
          }
        }
      }
    }
  }
  if (t.isIdentifier(path.node.id) && node.id.name === 'endAction') {
    node.params = node.params.concat(t.identifier('actionName'));
    if (t.isBlockStatement(node.body)) {
      let express = utils.addLog(path.node.id.name);
      node.body.body.unshift(express);
      for (let item of node.body.body) {
        if (t.isIfStatement(item)) {
          if (t.isExpressionStatement(item.consequent) && t.isCallExpression(item.consequent.expression)) {
            let subExpress = item.consequent.expression;
            if (t.isIdentifier(subExpress.callee) && subExpress.callee.name === 'spyReportEnd') {
              let subArgs = subExpress.arguments[0];
              if (t.isObjectExpression(subArgs)) {
                const attr = t.objectProperty(t.identifier('actionName'), t.identifier('actionName'));
                subArgs.properties = subArgs.properties.concat(attr);
              }
            }
          }
        }
      }
    }
  }
}

module.exports = {
  transExpressionStatement,
  transFunctionDeclaration
}

==> babel-plugin-house-1.0.11.tgz: package/src/mobxPatch.js <==
const babel = require('babel-core');
const t = require('babel-types');
const utils = require('./utils');

function transExpressionStatement(path, state) {
  if (!state.file.opts.filename.match('mobx.module.js')) return;
  const node = path.node;
  if (t.isCallExpression(node.expression)) {
    if (t.isIdentifier(node.expression.callee) && node.expression.callee.name === 'endAction') {
      let args = node.expression.arguments;
      args = args.concat(t.identifier('actionName'));
      node.expression.arguments = args;
    }
  }
}

function transFunctionDeclaration(path, state) {
  if (!state.file.opts.filename.match('mobx.module.js')) return;
  const node = path.node;
  if (t.isIdentifier(path.node.id) && node.id.name === 'executeAction') {
    if (t.isBlockStatement(node.body)) {
      let express = utils.addLog(path.node.id.name);
      node.body.body.unshift(express);
      for (let item of node.body.body) {
        if (t.isExpressionStatement(item) && t.isCallExpression(item.expression)) {
          if (t.isIdentifier(item.expression.callee) && item.expression.callee.name === 'endAction') {
            let args = item.expression.arguments;
            args = args.concat(t.identifier('actionName'));
            item.expression.arguments = args;
            break;
          }
        }
      }
    }
  }
  if (t.isIdentifier(path.node.id) && node.id.name === 'endAction') {
    node.params = node.params.concat(t.identifier('actionName'));
    if (t.isBlockStatement(node.body)) {
      let express = utils.addLog(path.node.id.name);
      node.body.body.unshift(express);
      for (let item of node.body.body) {
        if (t.isIfStatement(item)) {
          if (t.isExpressionStatement(item.consequent) && t.isCallExpression(item.consequent.expression)) {
            let subExpress = item.consequent.expression;
            if (t.isIdentifier(subExpress.callee) && subExpress.callee.name === 'spyReportEnd') {
              let subArgs = subExpress.arguments[0];
              if (t.isObjectExpression(subArgs)) {
                const attr = t.objectProperty(t.identifier('actionName'), t.identifier('actionName'));
                subArgs.properties = subArgs.properties.concat(attr);
              }
            }
          }
        }
      }
    }
  }
}

module.exports = {
  transExpressionStatement,
  transFunctionDeclaration
};
